<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Змяніць форму Атрымальнікі");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Змяніць форму Атрымальнікі");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "форма старонкі");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Вы можаце ўсталяваць больш аднаго атрымальніка, падзяляючы лісты з коскамі.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Захаванне атрымальніка ...");
define('VIEW_FORM_TABLES_HEADING', "Прагляд Форма табліцы");
define('VIEW_FORM_TABLES_BTN', "Прагляд Форма табліцы");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Выберыце табліцы для прагляду");
define('VIEW_FORM_TABLES_FILTER_READ', "Фільтр Чытанне паведамленняў");
?>